@@ -376,7 +376,7 @@ class Extractor:
                         final_res["document_no_full"] += res.group(0)
                         number = res.group(1)
 
-        res = re.search('([a-zA-Z]+/[a-zA-Z]+)\s*([0-9]+(\.[0-9]+)?)[—-]+([0-9]{4})', query)
+        res = re.search('([a-zA-Z]+/[a-zA-Z]+)\s*([0-9]+(\.[0-9]+)?)[—\-－]+([0-9]{4})', query)
         if res:
             another_number = res.group(0)
             final_res["document_no_full"] += ("" if final_res["document_no_full"] == "" else " ") + another_number
@@ -455,7 +455,7 @@ class Extractor:
 
 if __name__ == '__main__':
     et = Extractor()
-    res = et.extract_reference_no("〔2015〕")
+    res = et.extract_reference_no("JR/T0025.15-－2018")
     print(res)
     exit(0)
     print(datetime.today())
